@@ -3,7 +3,8 @@
 import pandas as pd
 
 import pdpipe as pdp
-from pdpipe.df import _DataFrameMethodTransformer
+from pdpipe.df.df_transformer import _DataFrameMethodTransformer
+from pdpipe import df
 
 
 def _test_df():
@@ -16,7 +17,7 @@ def _test_df():
 
 def test_df_set_axis():
     """Testing the ColDrop pipeline stage."""
-    df = _test_df()
+    df = _test_df()  # noqa: F811
     assert 'num1' in df.columns
     stage = pdp.df.set_index(keys='num2')
     res_df = stage.apply(df)
@@ -47,3 +48,20 @@ def test_df_set_axis():
     assert 'char' in res_df.columns
     assert list(res_df.index) == [2, 4]
     assert 'num2' in df
+
+
+def get_pipeline() -> pdp.PdPipeline:
+    return pdp.PdPipeline([
+        df.drop('char', axis=1),
+        df.set_index(keys='num2'),
+    ])
+
+
+def test_more_df():
+    df = _test_df()
+    pline = get_pipeline()
+    res_df = pline(df)
+    assert 'num1' in res_df.columns
+    assert 'num2' not in res_df.columns
+    assert 'char' not in res_df.columns
+    assert list(res_df.index) == [2, 4]
